import { SetUserProperties } from './types';
import type { User } from './user';
/**
 * @internal
 */
type WriteableUser = {
    -readonly [P in keyof User]: User[P];
};
/**
 * UserConfig DI interface.
 *
 * @public
 */
export interface UserConfig {
    /**
     * Exclude certain actions from tracking.
     *
     * See {@link UserPathHistory}
     */
    trackActionExclusions: unknown[];
    /**
     * Exclude certain paths from tracking.
     *
     * See {@link UserActionHistory}
     */
    trackPathExclusions: string[];
    /**
     * User property setter.
     *
     * @remarks
     * The user is typically set from the result of a LoginAck.
     */
    setUser(user: WriteableUser, properties: Partial<SetUserProperties>): User;
    /**
     * User property un-setter.
     */
    unsetUser(user: WriteableUser): User;
}
/**
 * Default UserConfig DI implementation.
 * @public
 */
export declare const defaultUserConfig: UserConfig;
/**
 * UserConfig DI key.
 *
 * @internal
 * @privateRemarks
 * Marked as internal to stop api-extractor becoming confused cross-linking tokens with the same name.
 */
export declare const UserConfig: import("@microsoft/fast-foundation").InterfaceSymbol<UserConfig>;
export {};
//# sourceMappingURL=config.d.ts.map